import matplotlib.pyplot as plt
import numpy as np
from matplotlib import rc

# Configure matplotlib to use LaTeX and Helvetica font
rc('font',**{'family':'sans-serif','sans-serif':['Helvetica']})
rc('text', usetex=True)

# Constants
a = 0.2
b = 0.2
mu_values = np.linspace(0.01, 0.99, 100)  # Vary mu
m_values = np.arange(0, 6)  # m from 0 to 5

# List of colors to be assigned for each m value
colors = ['tab:blue', 'tab:green', 'tab:red', 'tab:orange', 'tab:purple', 'tab:cyan']

# Residue functions for stability check
def residue_z0m_minus(m, mu):
    return - (np.pi * a * b) * np.sqrt(1 + m / a) / (mu - 1)

def residue_z1m_plus(m, mu):
    return (np.pi * a * b) * np.sqrt(1 + m / a) / (mu + 1)

# Fixed point y-coordinates
def y_coordinate_z0m_minus(m):
    return -np.sqrt(1 + m / a)

def y_coordinate_z1m_plus(m):
    return np.sqrt(1 + m / a)

plt.figure(figsize=(5, 2.5))

# Plot y-coordinates for each m value from 0 to 5, checking stability for each mu
for i, m in enumerate(m_values):
    y_z0m_minus = y_coordinate_z0m_minus(m)
    y_z1m_plus = y_coordinate_z1m_plus(m)
    
    stable_z0m = []
    unstable_z0m = []
    stable_z1m = []
    unstable_z1m = []
    
    for mu in mu_values:
        R_z0m = residue_z0m_minus(m, mu)
        R_z1m = residue_z1m_plus(m, mu)
        
        # Check stability for z0m-
        if 0 < R_z0m < 1:
            stable_z0m.append((mu, y_z0m_minus))
        else:
            unstable_z0m.append((mu, y_z0m_minus))
        
        # Check stability for z1m+
        if 0 < R_z1m < 1:
            stable_z1m.append((mu, y_z1m_plus))
        else:
            unstable_z1m.append((mu, y_z1m_plus))
    
    if stable_z0m:
        stable_z0m = np.array(stable_z0m)
        plt.plot(stable_z0m[:, 0], stable_z0m[:, 1], label=f'Stable $z^*_{{0m-}}$, m={m}', linestyle='-', linewidth=2, color=colors[i])
    if unstable_z0m:
        unstable_z0m = np.array(unstable_z0m)
        plt.plot(unstable_z0m[:, 0], unstable_z0m[:, 1], linestyle='--', linewidth=2, color=colors[i])

    if stable_z1m:
        stable_z1m = np.array(stable_z1m)
        plt.plot(stable_z1m[:, 0], stable_z1m[:, 1], label=f'Stable $z^*_{{1m+}}$, m={m}', linestyle='-', linewidth=2, color=colors[i])
    if unstable_z1m:
        unstable_z1m = np.array(unstable_z1m)
        plt.plot(unstable_z1m[:, 0], unstable_z1m[:, 1], linestyle='--', linewidth=2, color=colors[i])

plt.xlabel(r'$\mu$', fontsize=20)
plt.ylabel(r'$y^*_{0m-},y^*_{1m+}$', fontsize=20, rotation=90, labelpad=15)
plt.yticks(fontsize=20)
plt.xticks(fontsize=20)

output_file = "fig1a.pdf"
plt.savefig(output_file, dpi=150, bbox_inches='tight')

